==> elasticsearch-clojure-0.99.2.jar: project.clj <==
(defproject elastic/elasticsearch-clojure "0.99.2"
  :description "A low-level HTTP client for Elasticsearch"
  :url "https://github.com/elastic/elasticsearch-clojure"
  :license {:name "Apache License, Version 2.0"
            :url "https://www.apache.org/licenses/LICENSE-2.0"}
  :deploy-repositories [["snapshots" :clojars]
                        ["releases" :clojars]]
  :release-tasks [["vcs" "assert-committed"]
                  ["change" "version"
                   "leiningen.release/bump-version" "release"]
                  ["vcs" "commit"]
                  ["vcs" "tag"]
                  ["with-profile" "package" "deploy" "clojars"]
                  ["change" "version" "leiningen.release/bump-version"]
                  ["vcs" "commit"]
                  ["vcs" "push"]]
  :global-vars {*warn-on-reflection* false}
  :min-lein-version "2.0.0"
  :dependencies [[cheshire "5.6.1"]
                 [circleci/clj-yaml "0.5.5"
                  :exclusions [[org.clojure/clojure]]]
                 [clj-http "2.0.0"
                  :exclusions [slingshot]]
                 [prismatic/schema "1.1.0"]
                 [ring/ring-codec "1.0.1"]
                 [slingshot "0.12.2"]
                 [io.forward/yaml "1.0.3"]]
  :profiles {:dev {:dependencies [[org.clojure/clojure "1.8.0"]]}
             :1.6 {:dependencies [[org.clojure/clojure "1.6.0"]]}
             :1.7 {:dependencies [[org.clojure/clojure "1.7.0"]]}
             :package {:dependencies [[org.clojure/clojure "1.8.0"]]
                       :aot :all}}
  :aliases {"all" ["with-profile" "dev,1.6:dev,1.7:dev"]}
  :plugins []
  :aot :all
  :test-selectors {:default #(not (:integration %))
                   :integration :integration
                   :all (constantly true)})

==> elasticsearch-clojure-0.99.4.jar: project.clj <==
(defproject elastic/elasticsearch-clojure "0.99.4"
  :description "A low-level HTTP client for Elasticsearch"
  :url "https://github.com/elastic/elasticsearch-clojure"
  :license {:name "Apache License, Version 2.0"
            :url "https://www.apache.org/licenses/LICENSE-2.0"}
  :deploy-repositories [["snapshots" :clojars]
                        ["releases" :clojars]]
  :release-tasks [["vcs" "assert-committed"]
                  ["change" "version"
                   "leiningen.release/bump-version" "release"]
                  ["vcs" "commit"]
                  ["vcs" "tag"]
                  ["with-profile" "package" "deploy" "clojars"]
                  ["change" "version" "leiningen.release/bump-version"]
                  ["vcs" "commit"]
                  ["vcs" "push"]]
  :global-vars {*warn-on-reflection* false}
  :min-lein-version "2.0.0"
  :dependencies [[cheshire "5.6.1"]
                 [circleci/clj-yaml "0.5.5"
                  :exclusions [[org.clojure/clojure]]]
                 [clj-http "3.4.1"
                  :exclusions [slingshot]]
                 [org.clojure/core.async "0.2.395"
                  :exclusions [org.clojure/tools.analyzer
                               org.clojure/tools.analyzer.jvm]]
                 [org.clojure/tools.analyzer "0.6.9"]
                 [org.clojure/tools.analyzer.jvm "0.6.9"]
                 [ring/ring-codec "1.0.1"]
                 [slingshot "0.12.2"]
                 [io.forward/yaml "1.0.3"]]
  :profiles {:dev {:dependencies [[org.clojure/clojure "1.9.0-alpha14"]]}
             :1.6 {:dependencies [[org.clojure/clojure "1.6.0"]]}
             :1.7 {:dependencies [[org.clojure/clojure "1.7.0"]]}
             :package {:dependencies [[org.clojure/clojure "1.9.0-alpha14"]]
                       :aot :all}}
  :aliases {"all" ["with-profile" "dev,1.6:dev,1.7:dev"]}
  :plugins []
  :aot :all
  :test-selectors {:default #(not (:integration %))
                   :integration :integration
                   :all (constantly true)})
